@@ -41,16 +41,16 @@ class DjangoCreator(ProjectCreator):
         Creates a base Django project
         '''
         if os.path.exists(self._py):
-            django_dir = os.path.join(self._django_dir, self._project_name)
-            if os.path.exists(django_dir):
+            prj_dir = os.path.join(self._app_dir, self._project_name)
+            if os.path.exists(prj_dir):
                 if self._force:
-                    logging.warn('Removing existing django project')
-                    shutil.rmtree(django_dir)
+                    logging.warn('Removing existing project')
+                    shutil.rmtree(prj_dir)
                 else:
-                    logging.warn('Found existing django project; not creating (use --force to overwrite)')
+                    logging.warn('Found existing project; not creating (use --force to overwrite)')
                     return
-            logging.info('Creating Django project')
-            p = subprocess.Popen('cd {0} ; {1} startproject {2} > /dev/null'.format(self._django_dir, self._ve_dir + os.sep + self._project_name + \
+            logging.info('Creating project')
+            p = subprocess.Popen('cd {0} ; {1} startproject {2} > /dev/null'.format(self._app_dir, self._ve_dir + os.sep + self._project_name + \
             os.sep + 'bin' + os.sep + 'django-admin.py', self._project_name), \
             shell=True)
             os.waitpid(p.pid, 0)
@@ -71,8 +71,8 @@ class DjangoCreator(ProjectCreator):
         # set socket
         scr += '-s {0}.sock '.format(os.path.join(self._var_dir, self._project_name))
         # chdir for app
-        scr += '--chdir {0} '.format(os.path.join(self._django_dir, self._project_name))
-        scr += '--pp {0} '.format(os.path.join(self._django_dir))
+        scr += '--chdir {0} '.format(os.path.join(self._app_dir, self._project_name))
+        scr += '--pp {0} '.format(os.path.join(self._app_dir))
         # app settings
         scr += '--env DJANGO_SETTINGS_MODULE=settings -w \
 \"django.core.handlers.wsgi:WSGIHandler()\" '
